summaryrefslogtreecommitdiffstats
path: root/telecomm/java/android/telecomm/CallServiceSelector.java
diff options
context:
space:
mode:
Diffstat (limited to 'telecomm/java/android/telecomm/CallServiceSelector.java')
-rw-r--r--telecomm/java/android/telecomm/CallServiceSelector.java15
1 files changed, 8 insertions, 7 deletions
diff --git a/telecomm/java/android/telecomm/CallServiceSelector.java b/telecomm/java/android/telecomm/CallServiceSelector.java
index 74f05fe..cef9987 100644
--- a/telecomm/java/android/telecomm/CallServiceSelector.java
+++ b/telecomm/java/android/telecomm/CallServiceSelector.java
@@ -49,13 +49,14 @@ public abstract class CallServiceSelector extends Service {
}
@Override
- public void select(CallInfo callInfo, List<CallServiceInfo> callServiceInfos,
+ public void select(CallInfo callInfo, List<CallServiceDescriptor> descriptors,
ICallServiceSelectionResponse response) throws RemoteException {
+
// Ensure that we're running with the app's normal permission level
long ident = Binder.clearCallingIdentity();
try {
- response.setSelectedCallServiceInfos(
- CallServiceSelector.this.select(callInfo, callServiceInfos));
+ response.setSelectedCallServiceDescriptors(
+ CallServiceSelector.this.select(callInfo, descriptors));
} finally {
Binder.restoreCallingIdentity(ident);
}
@@ -91,10 +92,10 @@ public abstract class CallServiceSelector extends Service {
* This method is not called on the UI thread and is safe to block.
*
* @param callInfo The call being placed using the {@link CallService}s.
* @param callServiceInfos The details of the available {@link CallService}s with which to place
* the call.
* @return A list of prioritized {@link CallServiceInfo}s to use to complete the given call.
*/
- protected abstract List<CallServiceInfo> select(
- CallInfo callInfo, List<CallServiceInfo> callServiceInfos);
+ protected abstract List<CallServiceDescriptor> select(
+ CallInfo callInfo, List<CallServiceDescriptor> descriptors);
}
@@ -91,10 +92,10 @@ public abstract class CallServiceSelector extends Service {
*
* @param callInfo The call being placed using the {@link CallService}s.
- * @param callServiceInfos The details of the available {@link CallService}s with which to place
+ * @param descriptors The descriptors of the available {@link CallService}s with which to place
* the call.
@@ -91,10 +92,10 @@ public abstract class CallServiceSelector extends Service {
* the call.
- * @return A list of prioritized {@link CallServiceInfo}s to use to complete the given call.
+ * @return A list of prioritized call-service descriptors to use to complete the given call.
*/